From d93f538e29d34dd765e68cf721063c6bdaab7f29 Mon Sep 17 00:00:00 2001
From: Dmitry Shachnev <mitya57@gmail.com>
Date: Sat, 30 Sep 2017 23:38:29 +0300
Subject: [PATCH 1/2] qmake.pm: Add initial support for cross-building

---
 lib/Debian/Debhelper/Buildsystem/qmake.pm | 26 +++++++++++++++++++++++++-
 1 file changed, 25 insertions(+), 1 deletion(-)

diff --git a/lib/Debian/Debhelper/Buildsystem/qmake.pm b/lib/Debian/Debhelper/Buildsystem/qmake.pm
index c39c2474..e92c905f 100644
--- a/lib/Debian/Debhelper/Buildsystem/qmake.pm
+++ b/lib/Debian/Debhelper/Buildsystem/qmake.pm
@@ -8,7 +8,7 @@ package Debian::Debhelper::Buildsystem::qmake;
 
 use strict;
 use warnings;
-use Debian::Debhelper::Dh_Lib qw(error);
+use Debian::Debhelper::Dh_Lib qw(dpkg_architecture_value error is_cross_compiling);
 use parent qw(Debian::Debhelper::Buildsystem::makefile);
 
 our $qmake="qmake";
@@ -52,6 +52,15 @@ sub configure {
 
 	push @options, '-makefile';
 	push @options, '-nocache';
+	if (is_cross_compiling()) {
+		my $host_os = dpkg_architecture_value("DEB_HOST_ARCH_OS");
+		my %os_mkspec_mapping = (
+			'linux'    => 'linux-g++',
+			'kfreebsd' => 'gnukfreebsd-g++',
+			'hurd'     => 'hurd-g++',
+		);
+		push @options, ("-spec", $os_mkspec_mapping{$host_os});
+	}
 
 	if ($ENV{CFLAGS}) {
 		push @flags, "QMAKE_CFLAGS_RELEASE=$ENV{CFLAGS} $ENV{CPPFLAGS}";
@@ -68,6 +77,21 @@ sub configure {
 	push @flags, "QMAKE_STRIP=:";
 	push @flags, "PREFIX=/usr";
 
+	if (is_cross_compiling()) {
+		if ($ENV{CC}) {
+			push @flags, "QMAKE_CC=" . $ENV{CC};
+		} else {
+			push @flags, "QMAKE_CC=" . dpkg_architecture_value("DEB_HOST_GNU_TYPE") . "-gcc";
+		}
+		if ($ENV{CXX}) {
+			push @flags, "QMAKE_CXX=" . $ENV{CXX};
+		} else {
+			push @flags, "QMAKE_CXX=" . dpkg_architecture_value("DEB_HOST_GNU_TYPE") . "-g++";
+		}
+		push @flags, "QMAKE_LINK=\$(CXX)";
+		push @flags, "PKG_CONFIG=" . dpkg_architecture_value("DEB_HOST_GNU_TYPE") . "-pkg-config";
+	}
+
 	$this->mkdir_builddir();
 	$this->doit_in_builddir($qmake, @options, @flags, @_);
 }
-- 
2.14.2

